==> qmmp_2.2.3.orig.tar.bz2: qmmp-2.2.3/src/plugins/General/taskbar/translations/taskbar_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>TaskbarFactory</name>
    <message>
        <location filename="../taskbarfactory.cpp" line="28"/>
        <source>Taskbar Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="49"/>
        <source>About Taskbar Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="50"/>
        <source>Qmmp Taskbar Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="51"/>
        <source>This plugin adds support for progress indicator in the Windows taskbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>程式編寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="53"/>
        <source>Based on QtWinExtras module of the Qt Toolkit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="54"/>
        <source>QtWinExtras developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="55"/>
        <source>Ivan Vizir &lt;define-true-false@yandex.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="56"/>
        <source>The Qt Company Ltd.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_2.2.8.orig.tar.bz2: qmmp-2.2.8/src/plugins/General/taskbar/translations/taskbar_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>TaskbarFactory</name>
    <message>
        <location filename="../taskbarfactory.cpp" line="28"/>
        <source>Taskbar Plugin</source>
        <translation>工作列插件</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="49"/>
        <source>About Taskbar Plugin</source>
        <translation>關於工作列插件</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="50"/>
        <source>Qmmp Taskbar Plugin</source>
        <translation>Qmmp 工作列插件</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="51"/>
        <source>This plugin adds support for progress indicator in the Windows taskbar</source>
        <translation>此插件提供 Windows 工作列進度指示器的支援</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>程式編寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="53"/>
        <source>Based on QtWinExtras module of the Qt Toolkit</source>
        <translation>基於 Qt 工具組的 QtWinExtras 模組</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="54"/>
        <source>QtWinExtras developers:</source>
        <translation>QtWinExtras 開發者：</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="55"/>
        <source>Ivan Vizir &lt;define-true-false@yandex.com&gt;</source>
        <translation>Ivan Vizir &lt;define-true-false@yandex.com&gt;</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="56"/>
        <source>The Qt Company Ltd.</source>
        <translation>Qt 公司</translation>
    </message>
</context>
</TS>
